import { Ref } from 'vue';
import { BundledTheme } from 'shiki';
/**
 * The return type of the `useHighlighter` function.
 */
interface UseHighlighterReturn {
    highlightedCode: Ref<string>;
    highlightCode: (codeContent: string, themes: {
        light: BundledTheme;
        dark: BundledTheme;
    }) => Promise<void>;
}
/**
 * Custom hook to use the Shiki highlighter for syntax highlighting code content.
 *
 * @returns {Object} An object containing:
 * - `highlightedCode`: A ref that holds the highlighted HTML string.
 * - `highlightCode`: A function to highlight the provided code content based on the specified themes.
 */
export declare function useHighlighter(): UseHighlighterReturn;
export {};
