/**
 * Handle module invalidation in the Vite server and tracks watched files for changes.
 */
export declare class ModuleInvalidator {
    private watchedFiles;
    /**
     * Creates an instance of ModuleInvalidator.
     *
     * @param {Map<string, Set<string>>} [watchedFiles] - Optional initial set of watched files.
     */
    constructor(watchedFiles?: Map<string, Set<string>>);
    /**
     * Invalidates Vite server modules for all tracked files.
     *
     * @param {any} server - The Vite server instance.
     */
    invalidateModules(server: any): void;
    /**
     * Adds a file to the watch list and associates it with a given id.
     *
     * @param {string} filePath - The path of the file to watch.
     * @param {string} id - The identifier for the file.
     */
    addFile(filePath: string, id: string): void;
    /**
     * Clears all tracked watched files.
     */
    clearWatchedFiles(): void;
}
