import { CssTokenProcessor } from './css-token-processor';
import { Token } from './css-tokenizer';
import { TokenProcessorStrategyOptions } from './strategies/token-processor-strategy';
/**
 * Class for analyzing and identifying unique and duplicate CSS rules.
 */
export declare class CssRulesAnalyzer {
    private options;
    private cssProcessor;
    /**
     * Creates an instance of `CssRuleAnalyzer`.
     *
     * @param {CssTokenProcessor} cssProcessor - Instance of `CssTokenProcessor` for token processing.
     * @param {TokenProcessorStrategyOptions} [options] - Options for processing CSS tokens.
     */
    constructor(cssProcessor: CssTokenProcessor, options?: TokenProcessorStrategyOptions);
    /**
     * Sets the options for processing CSS tokens.
     *
     * @param {TokenProcessorStrategyOptions} options - The options to set.
     */
    setOptions(options: TokenProcessorStrategyOptions): void;
    /**
     * Analyzes multiple CSS inputs to identify unique and duplicate rules.
     * Filters out invalid or malformed CSS rules.
     *
     * @param {string[]} cssInputs - Array of CSS input strings.
     * @returns {{
     *   unique: Map<string, { rule: string; sources: string[] }>;
     *   duplicates: Map<string, { rule: string; sources: string[] }>;
     * }}
     */
    analyze(cssInputs: string[]): {
        unique: Map<string, {
            rule: string;
            sources: string[];
        }>;
        duplicates: Map<string, {
            rule: string;
            sources: string[];
        }>;
    };
    minifyRules(tokens: Token[]): string[];
    /**
     * Merges provided options with defaults.
     *
     * @param {TokenProcessorStrategyOptions} [options] - Options to merge with defaults.
     * @returns {Required<TokenProcessorStrategyOptions>} - The merged options.
     */
    private mergeOptions;
    /**
     * Generates a hash for a CSS rule.
     *
     * @param {string} rule - The CSS rule to hash.
     * @returns {string} - The hash of the rule.
     */
    private hashRule;
}
