import { Token } from '../css-tokenizer';
import { TokenProcessorStrategy, TokenProcessorStrategyOptions } from './token-processor-strategy';
/**
 * Strategy for processing and extracting content from `@layer` rules in CSS.
 */
export declare class LayerProcessor implements TokenProcessorStrategy {
    /** Options for the Token Processor Strategy. */
    private options;
    /**
     * Creates an instance of CssTokenProcessor.
     *
     * @param {TokenProcessorStrategyOptions} [options] - Default options for processing.
     */
    constructor(options?: TokenProcessorStrategyOptions);
    /**
     * Sets the options for the LayerProcessor.
     *
     * @param {TokenProcessorStrategyOptions} options - Options to update.
     */
    setOptions(options: TokenProcessorStrategyOptions): void;
    /**
     * Processes the tokens to extract and transform `@layer` content.
     *
     * @param {Token[]} tokens - The tokens to process.
     * @param {TokenProcessorStrategyOptions} [options] - Options for the processing strategy.
     * @returns {Token[]} - The processed CSS string.
     */
    execute(tokens: Token[], options?: TokenProcessorStrategyOptions): Token[];
    /**
     * Extracts the content of `@layer` rules, excluding the `@layer` declarations.
     *
     * @param {Token[]} tokens - The tokens to filter.
     * @returns {Token[]} - The filtered tokens containing only the layer content.
     */
    private extractLayerContents;
    /**
     * Discards tokens that represent standalone `@layer` declarations.
     *
     * @param {Token[]} tokens - The tokens to process.
     * @returns {Token[]} - The filtered tokens without `@layer` declarations.
     */
    private discardLayerDeclarations;
    /**
     * Merges provided options with defaults.
     *
     * @param {TokenProcessorStrategyOptions} [options] - Options to merge with defaults.
     * @returns {Required<TokenProcessorStrategyOptions>} - The merged options.
     */
    private mergeOptions;
}
