/**
 * Singleton class that manages the observation and execution of script elements within a dynamically updated preview content area.
 * It listens for changes to the DOM and executes new scripts as they are added to the `.preview-content` element.
 */
export declare class TemplScriptManager {
    private static instance;
    private domContentLoadedRegex;
    private constructor();
    /**
     * Returns the singleton instance of PreviewScriptManager.
     */
    static getInstance(): TemplScriptManager;
    /**
     * Initializes the observer and executes scripts within the initial content.
     */
    executeScriptsTick(): void;
    /**
     * Handles mutations and triggers script execution for added nodes.
     */
    private handleMutations;
    /**
     * Executes all script elements within the provided container.
     * @param {HTMLElement} container - The container element to search for script elements.
     */
    private executeScripts;
    /**
     * Processes and executes the provided script content.
     * @param {string} scriptContent - The script content to be processed and executed.
     */
    private processAndExecuteScript;
    /**
     * Creates a new script element with the provided content and executes it.
     * @param {string} scriptContent - The script content to be executed.
     */
    private createAndExecuteScript;
}
